| Title: | Rendering Word Clouds |
|---|---|
| Description: | Provides a way to display word clouds in R. The word cloud is a html widget, so you can use it in interactive documents and 'shiny' applications. |
| Authors: | Zhenxing Cheng [aut, cre] |
| Maintainer: | Zhenxing Cheng <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-05-08 05:47:42 UTC |
| Source: | https://github.com/cran/hwordcloud |
This function can create wordclouds by binding R and Highcharts.
Rendering word clouds using R + Highcharts
hwordcloud(text, size, width = "100%", height = NULL, theme = "sandsignika", itermName = "count", title = "", titleAlign = "center", titleSize = "20px", titleColor = "#333333", subtitle = "", subtitleAlign = "center", subtitleSize = "", subtitleColor = "#666666")hwordcloud(text, size, width = "100%", height = NULL, theme = "sandsignika", itermName = "count", title = "", titleAlign = "center", titleSize = "20px", titleColor = "#333333", subtitle = "", subtitleAlign = "center", subtitleSize = "", subtitleColor = "#666666")
text |
character vector; |
size |
numeric vector; |
width |
chart width, for example, "100%"; |
height |
chart height, for example, "400px"; |
theme |
chart theme, you can use these themes: darkgreen/darkblue/avocado/darkunica/gray/ gridlight/grid/sandsignika/sunset; |
itermName |
attribute in tooltip; |
title |
title; |
titleAlign |
title alignment, left/center/right; |
titleSize |
title size, like "20px"; |
titleColor |
title color, like "#333333"; |
subtitle |
subtitle; |
subtitleAlign |
subtitle alignment, left/center/right; |
subtitleSize |
subtitle size, like "16px"; |
subtitleColor |
subtitle color, like "#666666" |
hwordcloudRendering word clouds using R + Highcharts
library(hwordcloud) library(wordcloud2) df <- head(demoFreq, 50) if(interactive()){ hwordcloud(text = df$word, size = df$freq) }library(hwordcloud) library(wordcloud2) df <- head(demoFreq, 50) if(interactive()){ hwordcloud(text = df$word, size = df$freq) }
Output and render functions for using hwordcloud within Shiny applications and interactive Rmd documents.
hwordcloudOutput(outputId, width = "100%", height = "400px") renderHwordcloud(expr, env = parent.frame(), quoted = FALSE)hwordcloudOutput(outputId, width = "100%", height = "400px") renderHwordcloud(expr, env = parent.frame(), quoted = FALSE)
outputId |
output variable to read from |
width, height
|
Must be a valid CSS unit (like |
expr |
An expression that generates a hwordcloud |
env |
The environment in which to evaluate |
quoted |
Is |